/* Rev:$Revision: 1.0 $ */  

/******************************************************************************
 *
 * Copyright 1998-2007 NetBurner, Inc.  ALL RIGHTS RESERVED
 *   Permission is hereby granted to purchasers of NetBurner Hardware
 *   to use or modify this computer program for any use as long as the
 *   resultant program is only executed on NetBurner provided hardware.
 *
 *   No other rights to use this program or it's derivitives in part or
 *   in whole are granted.
 *
 *   It may be possible to license this or other NetBurner software for
 *   use on non NetBurner Hardware. Please contact Licensing@Netburner.com 
 *   for more information.
 *
 *   NetBurner makes no representation or warranties with respect to the 
 *   performance of this computer program, and specifically disclaims any 
 *   responsibility for any damages, special or consequential, connected 
 *   with the use of this program.
 *
 *   NetBurner, Inc
 *   5405 Morehouse Drive
 *   San Diego Ca, 92121
 *   http://www.netburner.com
 *
 *****************************************************************************
 
 The following example is designed to demonstrate using the NetBurner API to enable
 interrupts for any given eTPU channel.  This example will function with the default
 configuration of the eTPU system files.  The eTPU channels will all be configured as 
 GPIO inputs and an interrupt will be triggered when the channel detects a negative edge.
 At any time a key can be entered into UART0 and then this UART will output the number 
 of edges that have been detected on the channel. 
 */
 
#include "predef.h" 
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <taskmon.h>
#include <smarttrap.h>

#include <ETPUinit.h>    // eTPU intialization functions
#include <etpu.h>        // NetBurner eTPU API
#include <etpu_gpio.h>   // Freescale eTPU GPIO API

// Instruct the C++ compiler not to mangle the function name 
extern "C" 
{
void UserMain( void * pd);
}

// Name for development tools to identify this application 
const char * AppName="ETPU_IRQ";

int MY_ETPU_ISR(int channel);
DWORD ChannelEdgeCount[15];
DWORD LastTick[15];

// Main task 
void UserMain( void * pd)
{
    InitializeStack();
    if (EthernetIP==0)GetDHCPAddress(); 
    OSChangePrio( MAIN_PRIO );
    EnableAutoUpdate();
    EnableTaskMonitor();
    EnableSmartTraps();

    iprintf( "%s application started\r\n", AppName ); 
    
    eTPUInit();   // basic initialization for ETPU, puts all channels in hiz state
    
    //Now choose one of the following function pointers for the ISR with or without UART support
    //ETPU_Interrupt_Routine = MY_ETPU_ISR;     // Assign MY_ETPU_ISR to be the interrupt service routine for the eTPU
    ETPU_Interrupt_Routine_UART = MY_ETPU_ISR;  // MY_ETPU_ISR is the eTPU ISR with added UART support
                                                 
    // This loop initializes each channel for GPIO input with interrupts enabled      
    for(int channel = 0; channel<16; channel++)  
    {
      fs_etpu_gpio_cfg_input_trans(channel, FS_ETPU_GPIO_IP_FALLING);  //Freescale API for GPIO input
      ChannelEdgeCount[channel]=0;          // Edge count variable
      LastTick[channel] = 0;                // Last tick for software debouncing
      eTPUInterruptEnable(channel);         // Enable interrupts
    }   
        
    char input[5];
    
    while ( 1 )
    {
      gets(input);         // Wait for UART0 input to display nuber of negative edges
      iprintf("\r\n");
      for(int channel = 0; channel<16; channel++)
        iprintf("There have been %d Negative edegs on channel %d\r\n", ChannelEdgeCount[channel], channel);
    }
}

int MY_ETPU_ISR(int channel)
{
      if((LastTick[channel] + 1) < TimeTick)  // If last tick was 2 ticks ago(software debouncing)
      {
         ChannelEdgeCount[channel]++;         // Increment edge count
         LastTick[channel] = TimeTick;        // New last tick
      }
        
      eTPUEventClear(channel);                // Clear event so cahnnel can interrupt again
      return 0;
}
