/* Rev:$Revision: 1.0 $ */  

/******************************************************************************
 *
 * Copyright 1998-2007 NetBurner, Inc.  ALL RIGHTS RESERVED
 *   Permission is hereby granted to purchasers of NetBurner Hardware
 *   to use or modify this computer program for any use as long as the
 *   resultant program is only executed on NetBurner provided hardware.
 *
 *   No other rights to use this program or it's derivitives in part or
 *   in whole are granted.
 *
 *   It may be possible to license this or other NetBurner software for
 *   use on non NetBurner Hardware. Please contact Licensing@Netburner.com 
 *   for more information.
 *
 *   NetBurner makes no representation or warranties with respect to the 
 *   performance of this computer program, and specifically disclaims any 
 *   responsibility for any damages, special or consequential, connected 
 *   with the use of this program.
 *
 *   NetBurner, Inc
 *   5405 Morehouse Drive
 *   San Diego Ca, 92121
 *   http://www.netburner.com
 *
 *****************************************************************************
 
 The following example is designed to demonstrate using the NetBurner API to configure
 15 eTPU UART TX channels using the NetBurner API. 
 */
 
#include "predef.h" 
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <taskmon.h>
#include <smarttrap.h>
#include <string.h>
#include <pins.h>      // NetBurner GPIO Pins Class
#include <eTPUinit.h>  // NetBurner eTPU Initialization
#include <eTPU.h>      // NetBurner eTPU API

// Instruct the C++ compiler not to mangle the function name 
extern "C" 
{
void UserMain( void * pd);
}

// Name for development tools to identify this application 
const char * AppName="eTPU_15TX_UART";

// Global buffer used for sharing data between channels
char buffer[ETPU_UART_BUFFER_SIZE] __attribute__( ( aligned( 16 ) ) );  

// Main task 
void UserMain( void * pd)
{
    InitializeStack();
    if (EthernetIP==0)GetDHCPAddress(); 
    OSChangePrio( MAIN_PRIO );
    EnableAutoUpdate();
    EnableTaskMonitor();
    EnableSmartTraps();

    iprintf( "%s application started\r\n", AppName);

   
   /* 
   For Testing on the carrier you can use standard jumpers to connect 
   any of the eTPU channels to J2[22].  This will provide an easy
   way to run the ETPU UART TX channels to an rs-232 driver.  Pin
   J2[22] must be in hiz() and UART1 will no longer function.
   */
   J2[22].function(0);
   J2[22].hiz();

   eTPUInit();  // standard initialization for ETPU, puts all channels in hiz state

//int eTPUFunctionUARTTX(int channel, int baud_rate = 115200, int bits_per_data_word = 8, 
//                       int parity = FS_ETPU_UART_NO_PARITY, int priority = FS_ETPU_PRIORITY_MIDDLE );
   // Function call to create a file descriptor UART for one or two eTPU channels
   // The extra overloaded parameters are not needed since we want to configure 
   // a UART with the default options (115200 baud, 8 bits per word, no parity, middle priority)
   // The eTPUfd will now function like a standard serial file descritor for write calls
   // eTPU channel 8 can not be used since it is grounded on the development board
   // Channel 8 is fully functional and this will be corrected on boards after rev 1.08
   
   int eTPUfd[16]; // An array to hold our file descriptors
   
   for(int i = 0; i<16; i++)
      if(i!=8)
         eTPUfd[i] = eTPUFDUartOpen(-1, i);
         
   while(1)
   {
            
      for(int i = 0; i<16; i++)
      {
         if(i!=8)
         {
            siprintf(buffer, "I am eTPU channel %d\r\n", i);
            writeall(eTPUfd[i],buffer, strlen(buffer));
            OSTimeDly(2);
         }
      }
   }
}
