/* Rev:$Revision: 1.0 $ */  

/******************************************************************************
 *
 * Copyright 1998-2007 NetBurner, Inc.  ALL RIGHTS RESERVED
 *   Permission is hereby granted to purchasers of NetBurner Hardware
 *   to use or modify this computer program for any use as long as the
 *   resultant program is only executed on NetBurner provided hardware.
 *
 *   No other rights to use this program or it's derivitives in part or
 *   in whole are granted.
 *
 *   It may be possible to license this or other NetBurner software for
 *   use on non NetBurner Hardware. Please contact Licensing@Netburner.com 
 *   for more information.
 *
 *   NetBurner makes no representation or warranties with respect to the 
 *   performance of this computer program, and specifically disclaims any 
 *   responsibility for any damages, special or consequential, connected 
 *   with the use of this program.
 *
 *   NetBurner, Inc
 *   5405 Morehouse Drive
 *   San Diego Ca, 92121
 *   http://www.netburner.com
 *
 *****************************************************************************
 
 The following example is designed to demonstrate using the NetBurner API to configure
 a eTPU UART using the NetBurner file descriptor API. 
 */
 
#include "predef.h" 
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <taskmon.h>
#include <smarttrap.h>

#include <pins.h>      // NetBurner GPIO Pins Class
#include <eTPUinit.h>  // NetBurner eTPU Initialization
#include <eTPU.h>      // NetBurner eTPU API

// Instruct the C++ compiler not to mangle the function name 
extern "C" 
{
void UserMain( void * pd);
}

// Name for development tools to identify this application 
const char * AppName="eTPU_FD_UART";

#define UART_RX_CHANNEL (15)            // Defines which eTPU channel will be UART RX 
#define UART_TX_CHANNEL (14)            // Defines which eTPU channel will be UART TX  

// Global buffer used for sharing data between channels
char buffer[ETPU_UART_BUFFER_SIZE] __attribute__( ( aligned( 16 ) ) );  

// Main task 
void UserMain( void * pd)
{
    InitializeStack();
    if (EthernetIP==0)GetDHCPAddress(); 
    OSChangePrio( MAIN_PRIO );
    EnableAutoUpdate();
    EnableTaskMonitor();
    EnableSmartTraps();

    iprintf( "%s application started\r\n", AppName);

   
   /* 
   For Testing on the carrier you can use standard jumpers to connect 
   pins J2[19] to J2[21] and J2[20] to J2[22].  This will provide an easy
   way to run the ETPU UART for channels 15 and 16 to an rs-232 driver.  Pins
   J2[21] and J2[22] must be in hiz() and UART1 will no longer function.
   */
   J2[21].function(0);
   J2[22].function(0);
   J2[21].hiz();
   J2[22].hiz();

   eTPUInit();  // standard initialization for ETPU, puts all channels in hiz state

//int eTPUFunctionUARTTX(int channel, int baud_rate = 115200, int bits_per_data_word = 8, 
//                       int parity = FS_ETPU_UART_NO_PARITY, int priority = FS_ETPU_PRIORITY_MIDDLE );
   // Function call to create a file descriptor UART for one or two eTPU channels
   // The extra overloaded parameters are not needed since we want to configure 
   // a UART with the default options (115200 baud, 8 bits per word, no parity, middle priority)
   // The eTPUfd will now function like a standard serial file descritor
   int eTPUfd = eTPUFDUartOpen(UART_RX_CHANNEL, UART_TX_CHANNEL);
   while(1)
   {
      if(dataavail(eTPUfd)) 
      { 
         int num = read(eTPUfd, buffer, ETPU_UART_BUFFER_SIZE);  
         writestring(eTPUfd, "The eTPU RX channel read the character(s): ");
         writeall(eTPUfd, buffer, num);
         writestring(eTPUfd, "\r\n");
      }
   }
}
