/* Rev:$Revision: 1.0 $ */  

/******************************************************************************
 *
 * Copyright 1998-2007 NetBurner, Inc.  ALL RIGHTS RESERVED
 *   Permission is hereby granted to purchasers of NetBurner Hardware
 *   to use or modify this computer program for any use as long as the
 *   resultant program is only executed on NetBurner provided hardware.
 *
 *   No other rights to use this program or it's derivitives in part or
 *   in whole are granted.
 *
 *   It may be possible to license this or other NetBurner software for
 *   use on non NetBurner Hardware. Please contact Licensing@Netburner.com 
 *   for more information.
 *
 *   NetBurner makes no representation or warranties with respect to the 
 *   performance of this computer program, and specifically disclaims any 
 *   responsibility for any damages, special or consequential, connected 
 *   with the use of this program.
 *
 *   NetBurner, Inc
 *   5405 Morehouse Drive
 *   San Diego Ca, 92121
 *   http://www.netburner.com
 *
 *****************************************************************************
 
 The following example is designed to demonstrate using the Freescale API to enable 
 PWM functionality for each eTPU channel.  This can be done with the default eTPU system
 configuration.
 */
 
#include "predef.h" 
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <taskmon.h>
#include <smarttrap.h>

#include <eTPUinit.h>  // NetBurner eTPU Initialization
#include <eTPU.h>      // NetBurner eTPU API
#include <etpu_pwm.h>  // Freescale API for eTPU PWM


// Instruct the C++ compiler not to mangle the function name 
extern "C" 
{
void UserMain( void * pd);
}

// Name for development tools to identify this application 
const char * AppName="eTPU_PWM";
   
// Main task 
void UserMain( void * pd)
{
    InitializeStack();
    if (EthernetIP==0)GetDHCPAddress(); 
    OSChangePrio( MAIN_PRIO );
    EnableAutoUpdate();
    EnableTaskMonitor();
    EnableSmartTraps();

    iprintf( "%s application started\r\n",  AppName);
    
    eTPUInit();   // Standart eTPU initialization call
    
    // Each channel mush now be initialized to output PWM
    iprintf("0) %d\r\n", fs_etpu_pwm_init (0,	         // engine: A; channel: 0 
                             FS_ETPU_PRIORITY_HIGH,	   // priority: High 
                             1000,                       // freq: 1000 
                             500,	                     // duty: 1000 
                             FS_ETPU_PWM_ACTIVEHIGH,	  // polarity: FS_ETPU_PWM_ACTIVEHIGH 
                             FS_ETPU_TCR1,	           // timebase: TCR1 
                             etpu_a_tcr1_freq));	     // timebase_freq: Engine A, TCR1 frequency 
    iprintf("1) %d\r\n", fs_etpu_pwm_init (1,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                  
                             1000,	                 
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
    iprintf("2) %d\r\n", fs_etpu_pwm_init (2,	         
                             FS_ETPU_PRIORITY_HIGH,
                             1000,	                   
                             2000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
    iprintf("3) %d\r\n", fs_etpu_pwm_init (3,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                   
                             3000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
    iprintf("4) %d\r\n", fs_etpu_pwm_init (4,	        
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                
                             4000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
    iprintf("5) %d\r\n", fs_etpu_pwm_init (5,	        
                             FS_ETPU_PRIORITY_HIGH,
                             1000,	                  
                             5000,	                 
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
    iprintf("6) %d\r\n", fs_etpu_pwm_init (6,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	             
                             6000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	        
                             etpu_a_tcr1_freq));	      
    iprintf("7) %d\r\n", fs_etpu_pwm_init (7,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                  
                             7000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	      
    // Channel 8 can not be used on stand carrier rev 1.08 or lower
   //iprintf("8) %d\r\n", fs_etpu_pwm_init (8,	         
   //                          FS_ETPU_PRIORITY_HIGH,	
   //                          1000,	                   
   //                          8000,	                   
   //                          FS_ETPU_PWM_ACTIVEHIGH,
   //                          FS_ETPU_TCR1,	         
   //                          etpu_a_tcr1_freq));	     
   iprintf("9) %d\r\n", fs_etpu_pwm_init (9,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                  
                             8000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	        
                             etpu_a_tcr1_freq));	     
   iprintf("10) %d\r\n", fs_etpu_pwm_init (10,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	                   
                             9000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	      
   iprintf("11) %d\r\n", fs_etpu_pwm_init (11,	         
                             FS_ETPU_PRIORITY_HIGH,	
                             1000,	               
                             9500,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	    
   iprintf("12) %d\r\n", fs_etpu_pwm_init (12,	       
                             FS_ETPU_PRIORITY_HIGH,	
                             100000,	                  
                             2000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	   
   iprintf("13) %d\r\n", fs_etpu_pwm_init (13,	        
                             FS_ETPU_PRIORITY_HIGH,	
                             100000,	               
                             4000,	                  
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     
   iprintf("14) %d\r\n", fs_etpu_pwm_init (14,	       
                             FS_ETPU_PRIORITY_HIGH,
                             100000,	                
                             6000,	                  
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	
   iprintf("15) %d\r\n", fs_etpu_pwm_init (15,	       
                             FS_ETPU_PRIORITY_HIGH,
                             100000,	                  
                             8000,	                   
                             FS_ETPU_PWM_ACTIVEHIGH,	
                             FS_ETPU_TCR1,	         
                             etpu_a_tcr1_freq));	     

    while ( 1 )
    {
       OSTimeDly( TICKS_PER_SECOND );
    }
}
