/* Rev:$Revision: 1.0 $ */  

/******************************************************************************
 *
 * Copyright 1998-2007 NetBurner, Inc.  ALL RIGHTS RESERVED
 *   Permission is hereby granted to purchasers of NetBurner Hardware
 *   to use or modify this computer program for any use as long as the
 *   resultant program is only executed on NetBurner provided hardware.
 *
 *   No other rights to use this program or it's derivitives in part or
 *   in whole are granted.
 *
 *   It may be possible to license this or other NetBurner software for
 *   use on non NetBurner Hardware. Please contact Licensing@Netburner.com 
 *   for more information.
 *
 *   NetBurner makes no representation or warranties with respect to the 
 *   performance of this computer program, and specifically disclaims any 
 *   responsibility for any damages, special or consequential, connected 
 *   with the use of this program.
 *
 *   NetBurner, Inc
 *   5405 Morehouse Drive
 *   San Diego Ca, 92121
 *   http://www.netburner.com
 *
 *****************************************************************************
 
 The following example is designed to demonstrate using the Freescale API to configure
 the eTPU for SPI to communicate with an A2D IC.  SPI is one of the functions that is affected
 by an internal eTPU malloc bug so the channel can not be initialized to GPIO first, which 
 is why we can not use the standard eTPUinit() function. 
 
 This is an example for connecting the eTPU SPI peripheral to the Microchip MCP3304 A2D
 The data sheet for this Microchip part can be found here: http://ww1.microchip.com/downloads/en/devicedoc/21697b.pdf
 eTPU channel 14 is the SPI clk and should be connected to the CLK on the MCP3304
 eTPU channel 13 is the SPI Data In and should be connected to the Dout on the MCP3304
 eTPU channel 15 is the SPI Data Out and should be connected to the Din on the MCP3304
 eTPU channel 12 is GPIO used for an SPI CS and should be connected to the /CS on the MCP3304
 The A2D channel to be read must be inputted through UART0 to start conversion 
 */
#include "predef.h" 
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <dhcpclient.h>
#include <taskmon.h>
#include <smarttrap.h>
#include <stdlib.h>

#include <pins.h>      // NetBurner GPIO Pins Class
#include <eTPUinit.h>  // NetBurner eTPU Initialization
#include <eTPU.h>      // NetBurner eTPU API
#include <etpu_spi.h>  // Freescale API for eTPU SPI

// Instruct the C++ compiler not to mangle the function name 
extern "C" 
{
void UserMain( void * pd);
}

// Name for development tools to identify this application 
const char * AppName="eTPU_SPI";

// Assign A2D Chip Select to be eTPU channel 12 GPIO
#define A2D_CS    (J2[18])

DWORD ADChannel = 0x0;  // The A2D channel we are reading
DWORD A2DRX;         
DWORD A2DTX;   
char input[35];
int IntInput;

// Main task 
void UserMain( void * pd)
{
    InitializeStack();
    if (EthernetIP==0)GetDHCPAddress(); 
    OSChangePrio( MAIN_PRIO );
    EnableAutoUpdate();
    EnableTaskMonitor();
    EnableSmartTraps();
    
    iprintf( "%s application started\r\n", AppName ); 
    
    MOD5234_etpu_init();      // Basic init call to load micro-code on eTPU 
    MOD5234_etpu_start();     // Basic start call to start eTPU timers 
    
    // initialize eTPU channels for SPI. 13 = DataIn, 14 = Clock, 15 = DataOut
    fs_etpu_spi_init(14, FS_ETPU_PRIORITY_MIDDLE, 1000000, FS_ETPU_SPI_SHIFT_DIR_MSB,
                     FS_ETPU_SPI_CLK_POL_POS, 20,FS_ETPU_TCR1, etpu_a_tcr1_freq );
    // Initialize other channels for GPIO
    for( int ETPU_Channel = 0; ETPU_Channel < 13; ETPU_Channel++)  // initizlize GPIO channels
         eTPUFunctionGPIO( ETPU_Channel, FS_ETPU_PRIORITY_MIDDLE);
   
   
   eTPUEventPoll(14, 5);   // Initializing the SPI can trigger an event that must be cleared
   eTPUEventClear(14);     // clear the event
   iprintf("\r\n");
   
   while(1)
   {
      iprintf("Please input channel number you wish to read: ");
      gets(input);           // Wait for channel nuber to be inputted
      iprintf("\r\n"); 
      IntInput = atoi(input);  // Convert the ascii channel to an integer
      if( (IntInput > -1) && (IntInput < 8) )    // If a valid channel
      {
         ADChannel = IntInput;
         A2D_CS = 0;                                     // assert the chip select eTPU channel
         A2DTX = ( (0xC <<  16) | ( ADChannel << 15) );  // Create A2D command word (look at data sheet for MCP3304)
         
         fs_etpu_spi_transmit_data(14, A2DTX);   // Send the command out the eTPU SPI port
         eTPUEventPoll(14);                      // Poll for eTPU SPI event
         eTPUEventClear(14);                     // clear the event
         A2D_CS = 1;                             // de-assert the chip select
         A2DRX = (fs_etpu_spi_get_data(14) & 0xFFF);  // Read the incomming data word from the A2D
         iprintf("The result for channel %d is %X\r\n", ADChannel ,A2DRX);  // print the result
      }
      else
         iprintf("That channel does not exist, channel must be between 0-7\r\n");
   }


}
